@@ -25,4 +25,7 @@ def get_all_repos():
     for repo in os.listdir(REPOS_DIR):
         repo_path = os.path.join(REPOS_DIR, repo)
         if os.path.isdir(repo_path):
-            yield repo, repo_path
\ No newline at end of file
+            yield repo, repo_path
+
+class KnownError(Exception):
+    pass
\ No newline at end of file
